<?php
class OG_ControllerPublic_Thread extends XFCP_OG_ControllerPublic_Thread
{
    public function actionSave()
    {
        $retVal = parent::actionSave();
        
        $threadId = $this->_input->filterSingle('thread_id', XenForo_Input::UINT);

        $ftpHelper = $this->getHelper('ForumThreadPost');
        list($thread, $forum) = $ftpHelper->assertThreadValidAndViewable($threadId);

        $this->_assertCanEditThread($thread, $forum);

        $dwInput = $this->_input->filter(array(
            'ogimage' => XenForo_Input::STRING,
            'ogtitle' => XenForo_Input::STRING,
        ));
        
        $attachmentHash = $this->_input->filterSingle('attachment_hash', XenForo_Input::STRING);

        $threadModel = $this->_getThreadModel();

        $dw = XenForo_DataWriter::create('XenForo_DataWriter_Discussion_Thread');
        $dw->setExistingData($threadId);
        $dw->bulkSet($dwInput);
        $dw->setExtraData(XenForo_DataWriter_Discussion_Thread::DATA_FORUM, $forum);
        if(!empty($attachmentHash))
        {
            $dw->setExtraData(OG_DataWriter_Discussion_Thread::DATA_ATTACHMENT_HASH, $attachmentHash);
        }
        $dw->save();

        $this->_updateModeratorLogThreadEdit($thread, $dw);

        return $retVal;
    }
    public function actionEdit()
    {
        $this->_assertRegistrationRequired();

        $threadId = $this->_input->filterSingle('thread_id', XenForo_Input::UINT);

        $ftpHelper = $this->getHelper('ForumThreadPost');
        list($thread, $forum) = $ftpHelper->assertThreadValidAndViewable($threadId);

        $this->_assertCanEditThread($thread, $forum);

        $threadModel = $this->_getThreadModel();
        $attachmentModel = $this->_getAttachmentModel();
        
        $attachmentParams = $this->_getForumModel()->getAttachmentParams($forum, array(
			'thread_id' => $thread['thread_id']
		));
        $attachmentParams['content_type'] = 'ogimage';
        
        $attachments = $attachmentModel->getAttachmentsByContentId('ogimage', $threadId);
                
        $viewParams = array(
                'thread' => $thread,
                'forum' => $forum,

                'prefixes' => $this->_getPrefixModel()->getUsablePrefixesInForumsForced($forum['node_id'], null, $thread['prefix_id']),

                'nodeBreadCrumbs' => $ftpHelper->getNodeBreadCrumbs($forum),

                'canLockUnlockThread' => $threadModel->canLockUnlockThread($thread, $forum),
                'canStickUnstickThread' => $threadModel->canStickUnstickThread($thread, $forum),

                'canDeleteThread' => $threadModel->canDeleteThread($thread, $forum, 'soft'),
                'canHardDeleteThread' => $threadModel->canDeleteThread($thread, $forum, 'hard'),
            
            'attachmentParams' => $attachmentParams,
            'attachments' => $attachmentModel->prepareAttachments($attachments),
            'attachmentConstraints' => $attachmentModel->getAttachmentConstraints(),

                'canAlterState' => array(
                        'visible' => $threadModel->canAlterThreadState($thread, $forum, 'visible'),
                        'moderated' => $threadModel->canAlterThreadState($thread, $forum, 'moderated'),
                        'deleted' => $threadModel->canAlterThreadState($thread, $forum, 'deleted'),
                ),

                'showForumLink' => $this->_input->filterSingle('showForumLink', XenForo_Input::BOOLEAN)
        );

        if ($this->_input->filterSingle('_listItemEdit', XenForo_Input::UINT))
        {
                return $this->responseView('XenForo_ViewPublic_Thread_ListItemEdit', 'thread_list_item_edit', $viewParams);
        }
        else
        {
                return $this->responseView('XenForo_ViewPublic_Thread_Edit', 'thread_edit', $viewParams);
        }
    }
}